#!/bin/bash

LANG=C
set -u
#
# dnsbl-check-standalone.sh
#
# By Damon Tajeddini (dta)
# # 10.03.2009 , heise
# 
# als nagios-plugin rbe Sep. 2009
# geandert Juni 2011, rbe
#
#MAIL_RCPT="lihas@lihas.de"

. /usr/lib/nagios/plugins/utils.sh


DNSBLlist=`grep -v ^# <<!
cbl.abuseat.org
dnsbl.ahbl.org
ircbl.ahbl.org
virbl.dnsbl.bit.nl
blackholes.five-ten-sg.com
dnsbl.inps.de
ix.dnsbl.manitu.net
no-more-funn.moensted.dk
combined.njabl.org
dnsbl.njabl.org
dnsbl.sorbs.net
bl.spamcannibal.org
bl.spamcop.net
sbl.spamhaus.org
xbl.spamhaus.org
pbl.spamhaus.org
dnsbl-1.uceprotect.net
# dnsbl-2.uceprotect.net
# dnsbl-3.uceprotect.net
psbl.surriel.com
# l2.apews.org
dnsrbl.swinog.ch
db.wpbl.info
!`

# reverse IP address bytes
convertIP()
{
 set `IFS=".";echo $1`
 echo $4.$3.$2.$1
}

usage()
{
 echo "Usage: $0 [-H &lt;host&gt;|-p]"
 echo " -H IP address to check"
 echo " -F FQDN to check"
 echo " -p Print list of DNSBLs"
 exit 3
}

# Checks the IP with list of DNSBL servers
check()
{
 ret_value=$STATE_OK
 blacklisted=""
 for i in $DNSBLlist
 do
   if dig $ip_arpa.$i +short | grep -q "^127.0.0."
   then
     ret_value=$STATE_CRITICAL
     blacklisted+="$i,"
   fi
 done
 blacklisted=${blacklisted%,}
 if [ "$ret_value" = "$STATE_OK" ]; then 
   echo  "DNSBL OK for $ip" 
 else
   echo  "$ip blacklisted on: $blacklisted"
 fi
 exit $ret_value
} # check

case $1 in
 -H)
 if [ -z "$2" ]; then
   echo "ip address missing"
   exit $STATE_UNKNOWN
 fi
 ip=$2
 ip_arpa=`convertIP $ip`
 check;;

 -p)
 for i in $DNSBLlist
 do
 echo $i
 done
 exit $STATE_UNKNOWN;;

 --help)
 usage
 exit;;

 *)
 if [ -z "$1" ]; then
 usage
 fi
 echo "unknown command: $1"
 exit $STATE_UNKNOWN;;
esac
